// Author: Witold Jarnicki

#include <cassert>
#include <cstdio>
#include <iostream>
#include <vector>

using namespace std;

int kNumBits = 14;
int kNumStates = 0;
int kMask = 0;

vector<bool> visited;
vector<bool> from;
vector<int> v;

int Log2(const int n) {
  int k = 0;
  while (1 << k <= n) if (1 << k == n) return k; else ++k;
  return -1;
}

void Init() {
  kNumStates = 1 << (2 * kNumBits);
  kMask = (1 << kNumBits) - 1;
  visited.clear();
  visited.resize(kNumStates, false);
  v.clear();
  from.clear();
  from.resize(kNumStates, 0);
}

void Split(const int state, int* left, int *right) {
  *left = state & kMask;
  *right = state >> kNumBits;
}

int Combine(const int left, const int right) {
  return left + (right << kNumBits);
}

int Sibling(int state) {
  if (state == 0) return 0;
  int left, right;
  Split(state, &left, &right);
  int max_power = 1, power = 1;
  while (power <= left || power <= right) {
    max_power = power;
    power *= 2;
  }
  if (left & max_power) if (!(right & max_power)) return Combine(left ^ max_power, right ^ max_power);
  if (!(left & max_power)) if (right & max_power) return Combine(left ^ max_power, right ^ max_power);
  assert(false);
}

bool Valid(int left, int right) {
  if (left == 0 || right == 0) return true;
  int max_power = 1, power = 1;
  while (power <= left || power <= right) {
    max_power = power;
    power *= 2;
  }
  return !(left & max_power) || !(right & max_power);
}

void Visit(int state, const int left) {
  if (state == -1) return;
  for (int i = 0; i < 2; ++i) {
    if (!visited[state]) {
      // cerr << "visit " << state << endl;
      visited[state] = true;
      from[state] = left;
      v.push_back(state);
    }
    state = Sibling(state);
  }
}

int FwdLeft(const int b, const int state) {
  // cerr << b << ' ' << state << endl;
  int left, right;
  Split(state, &left, &right);
  if (left & ((1 << b) - 1)) return -1;
  left += 1 << b;
  if (Valid(left, right)) return Combine(left, right); else return -1;
}

int FwdRight(const int b, const int state) {
  int left, right;
  Split(state, &left, &right);
  if (right & ((1 << b) - 1)) return -1;
  right += 1 << b;
  if (Valid(left, right)) return Combine(left, right); else return -1;
}

int BackLeft(const int b, const int state) {
  int left, right;
  Split(state, &left, &right);
  if (left & ((1 << b) - 1)) return -1;
  left -= 1 << b;
  if (left < 0) return -1;
  if (Valid(left, right)) return Combine(left, right); else return -1;
}

int BackRight(const int b, const int state) {
  int left, right;
  Split(state, &left, &right);
  if (right & ((1 << b) - 1)) return -1;
  right -= 1 << b;
  if (right < 0) return -1;
  if (Valid(left, right)) return Combine(left, right); else return -1;
}

void Decode(int state, vector<int>::reverse_iterator it) {
  if (state == 0) return;
  for (int i = 0; i < 2; ++i) {
    if (visited[state]) {
      if (!from[state]) {
        // left
        int parent = BackLeft(*it, state);
        if (parent != -1) {
          ++it;
          Decode(parent, it);
          printf("l");
          return;
        }
      } else {
        // right
        int parent = BackRight(*it, state);
        if (parent != -1) {
          ++it;
          Decode(parent, it);
          printf("r");
          return;
        }
      }
    }
    state = Sibling(state);
  }
}

void Solve() {
  int n;
  scanf("%d", &n);
  vector<int> b(n);
  for (int i = 0; i < n; ++i) scanf("%d", &b[i]);
  int total = 0;
  for (int i = 0; i < n; ++i) total += b[i];
  for (int i = 0; i < n; ++i) b[i] = Log2(b[i]);

  if (Log2(total) == -1) {
    printf("no\n");
    return;
  }
  kNumBits = 1 + Log2(total);

  Init();
  Visit(0, false);

  for (int i = 0; i < n; ++i) {
    vector<int> old_v;
    old_v.swap(v);
    for (int j = 0; j < old_v.size(); ++j) {
      const int s = old_v[j];
      Visit(FwdLeft (b[i], s), false);
      Visit(FwdRight(b[i], s), true );
    }
  }

  if (!visited[total]) {
    printf("no\n");
    return;
  }

  Decode(total, b.rbegin());
  printf("\n");
}

int main() {
  int T;
  scanf("%d", &T);
  while (T--) Solve();
  return 0;
}
