// Author: Arkadiusz Pawlik
// Same as sol1, but encodes states in integers.

#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

vector<int> data;

typedef pair<char, int> edge;

struct state {
  int left, right;  // left != 0
  state() : left(0), right(0) {}
  void extend(int my_index, int next_val, vector<pair<state, edge> > *output);
  void rotate();
  bool can_extend_left(int number) const;
  void extend_left(int number);
  bool is_final() const;
};

int largest_power(int v) {
  v |= (v >> 1);
  v |= (v >> 2);
  v |= (v >> 4);
  v |= (v >> 8);
  return v - (v >> 1);
}

void state::rotate() {
  swap(left, right);
  if (left < right) {
    int p = largest_power(right);
    right -= p;
    left += p;
  }
}

bool state::can_extend_left(int number) const {
  if (!(left & (number - 1))) return true;
  if (left > right && number > left && left == largest_power(left)) return true;
  return false; 
}

void state::extend_left(int number) {
  if (number > left) {
    right += left;
    left = number;
  } else {
    left += number;
  }
}

bool state::is_final() const {
  return right == 0 && left == largest_power(left);
}

void state::extend(int my_index, int next_val,
                   vector<pair<state, edge> > *output) {
  pair<state, edge> next;
  next.second.second = my_index;
  next.first = *this;
  if (next.first.can_extend_left(next_val)) {
    next.first.extend_left(next_val);
    next.second.first = 'l';
    output->push_back(next);
  }
  next.first = *this;
  next.first.rotate();
  if (next.first.can_extend_left(next_val)) {
    next.first.extend_left(next_val);
    next.first.rotate();
    next.second.first = 'r';
    output->push_back(next);
  }
}

bool operator<(const state &a, const state &b) {
  if (a.left != b.left) return a.left < b.left;
  else return a.right < b.right;
}

bool state_equal(const pair<state, edge> &a, const pair<state, edge> &b) {
  return a.first.left == b.first.left && a.first.right == b.first.right;
}

void alg() {
  vector<vector<pair<state, edge> > > pos(data.size()+1);
  pos[0].push_back(make_pair(state(), make_pair('\0', -1)));
  for (int i = 0; i < data.size(); ++i) {
    int next_val = data[i];
    for (int j = 0; j < pos[i].size(); ++j) {
      state &s = pos[i][j].first;
      s.extend(j, next_val, &(pos[i+1]));
    }
    sort(pos[i+1].begin(), pos[i+1].end());
    pos[i+1].resize(unique(pos[i+1].begin(), pos[i+1].end(), state_equal)
                    - pos[i+1].begin());
  }
  if (pos[pos.size()-1].empty()) {
    cout << "no" << endl;
    return;
  }
  string result;
  int idx = -1;
  for (int i = 0; i < pos[pos.size()-1].size(); ++i) {
    if (pos[pos.size()-1][i].first.is_final()) {
      idx = i;
      break;
    }
  }
  if (idx == -1) {
    cout << "no" << endl;
    return;
  }
  pair<state, edge> step = pos[pos.size()-1][idx];
  for (int i = pos.size()-1; i > 0; --i) {
    result.push_back(step.second.first);
    step = pos[i-1][step.second.second];
  }
  reverse(result.begin(), result.end());
  cout << result << endl;
}

int main() {
  ios::sync_with_stdio(false);
  int c;
  cin >> c;
  while(c--) {
    int n;
    cin >> n;
    data.clear();
    while (n--) {
      int k;
      cin >> k;
      data.push_back(k);
    }
    alg();
  }
}
