#include <stdio.h>
#include <stdlib.h>
#include <string.h>
// author: Grzegorz Herman

#include <algorithm>
#include <iostream>
#include <queue>
#include <string>
#include <tuple>
#include <unordered_map>
#include <unordered_set>
#include <utility>
#include <vector>
using namespace std;

const int INF = 1000000000;

struct node;
typedef tuple<node*,node*,int> wedge;

struct node
{
    unordered_map<node*,int> edges;
    node * link;
    wedge best;

    node() : edges(), link(this), best(nullptr, nullptr, INF)
    {
    }

    node * find()
    {
        return (link == this) ? this : (link = link->find());
    }
};

wedge replacement(node * u, node * v)
{
    wedge r(nullptr, nullptr, INF);
    vector<node*> C;
    queue<node*> Q;
    C.push_back(u);
    Q.push(u);
    while (!Q.empty())
    {
        auto u = Q.front(); Q.pop();
        if (u == v)
        {
            r = u->best;
            break;
        }
        for (auto ww: u->edges)
            if (get<2>(ww.first->best) == INF)
            {
                ww.first->best = (ww.second < get<2>(u->best)) ? wedge(u, ww.first, ww.second) : u->best;
                C.push_back(ww.first);
                Q.push(ww.first);
            }
    }
    for (auto u : C)
        u->best = wedge(nullptr, nullptr, INF);
    return r;
}

struct vft
{
    vector<vector<pair<int,int>>>   data;

    vft(int m) : data(m, vector<pair<int,int>>(1, make_pair(-1,0)))
    {
    }

    void update(int t, int i, int v)
    {
        for (; i < (int)data.size(); i |= i+1)
        {
            int w = data[i].back().second + v;
            if (data[i].back().first == t)
                data[i].back().second = w;
            else
                data[i].emplace_back(t, w);
        }
    }

    int prefsum(int t, int i) const
    {
        int sum = 0;
        for (; i >= 0; i = (i&(i+1))-1)
            sum += (lower_bound(data[i].begin(), data[i].end(), make_pair(t+1, 0)) - 1)->second;
        return sum;
    }
};

void testcase()
{
    int n, m;
    cin >> n >> m;
    vector<pair<int,pair<int,int>>> I(m);
    for (int i=0; i<m; ++i)
        cin >> I[i].second.first >> I[i].second.second >> I[i].first;
    sort(I.begin(), I.end(), greater<pair<int,pair<int,int>>>());
    vector<node> V(n+1);
    vft T(m);
    for (int i=0; i<m; ++i)
    {
        auto e = I[i];
        auto u = V[e.second.first].find();
        auto v = V[e.second.second].find();
        if (u == v)
        {
            auto r = replacement(&V[e.second.first], &V[e.second.second]);
            T.update(i, get<2>(r), -I[get<2>(r)].first);
            get<0>(r)->edges.erase(get<1>(r));
            get<1>(r)->edges.erase(get<0>(r));
        }
        else
            u->link = v;
        T.update(i, i, +I[i].first);
        V[e.second.first].edges[&V[e.second.second]] = i;
        V[e.second.second].edges[&V[e.second.first]] = i;
    }
    int q;
    int t = 0;
    for (cin >> q; q; --q)
    {
        int l, h;
        cin >> l >> h;
        l -= t; h -= t;
        l = upper_bound(I.begin(), I.end(), make_pair(l, make_pair(0, 0)), greater<pair<int,pair<int,int>>>()) - I.begin();
        h = upper_bound(I.begin(), I.end(), make_pair(h+1, make_pair(0, 0)), greater<pair<int,pair<int,int>>>()) - I.begin();
        t = T.prefsum(l-1, m-1) - T.prefsum(l-1, h-1);
        cout << t << endl;
    }
}

int main()
{
    int z;
    for (cin >> z; z; --z)
        testcase();
    return 0;
}
