// Author: Lech Duraj (link-cut by Igor Adamski)

#include "ver.h"
#include <bits/stdc++.h>
using namespace std;
typedef long long LL;
typedef long double LD;
typedef vector<int> VI;
typedef pair<int,int> PII;
#define REP(i,n) for(int i=0;i<(n);++i)
#define SIZE(c) ((int)((c).size()))
#define FOR(i,a,b) for (int i=(a); i<(b); ++i)
#define FWD(i,a,b) for (int i=(a); i<(b); ++i)
#define FOREACH(i,x) for (__typeof((x).begin()) i=(x).begin(); i!=(x).end(); ++i)
#define FORD(i,a,b) for (int i=((int)(a))-1; i>=(b); --i)
#define BCK(i,a,b) for (int i=(a); i>(b); --i)
#define ALL(u) (u).begin(),(u).end()
#define PB push_back
#define ST first
#define ND second

// struktura dynamicznych drzew
// - modify(a, b, arg) wykonuje operacje (np dodawanie stalej)
// na kazdym wierzcholku na sciezce [a, b]
// - query(a, b) zwraca wynik innej operacji (np suma) na wszystkich
// wartosciach wierzcholkow na sciezce [a, b]
// - wszystkie operacje nalezy zaimplementowac tak jakbysmy pisali drzewo
// przedzialowe, a node_t to jest to co trzymamy w kazdym przedziale
// - UWAGA: wszystkie operacje poza find_root moga zmienic korzen !

typedef PII node_t;
typedef PII modify_t; // typ wartosci dzialajacych na wartosci w wierzcholach

// dzialamy na wierzcholek a wartoscia b
node_t op_modify(node_t a, modify_t b) { return b.first==-1 ? a : b; }

// jesli na wartosci x chcemy zadzialac a, a nastepie b, to tak jakbysmy zadzialali na x op_buf(a, b)
modify_t op_buf(modify_t a, modify_t b) { return b; }

// to tak jakbysmy laczyli dwa przedzialy bazowe w drzewie przedzialowym
node_t op_query(node_t a, node_t b) { 
    if (a.ND<b.ND)
        return b;
    else
        return a;
}

const node_t NODE_INIT = node_t(-1, 0); // poczatkowe wartosci na wierzcholkach
const modify_t MODIFY_NEUTRAL = PII(-1, 0); // op_modify(x, MODIFY_NEUTRAL) = x
struct link_cut_tree {
struct node {
    node *par, *child[2];
    bool rev;
    modify_t buf;
    node_t val, res;
};

vector<node> _node;

#define _left(x) x->child[0]
#define _right(x) x->child[1]

void init(int n) { // tworzy las n drzew jednowierzcholkowych
    _node.assign(n, node{NULL, {NULL, NULL}, 0, MODIFY_NEUTRAL, NODE_INIT, NODE_INIT}
);

}

void link(int _a, int _b) { // ZALOZENIE: find_root(a) != find_root(b)
    node *a = &_node[_a], *b = &_node[_b];
    _change_root(a); a->par = b;
}

void cut(int _a, int _b) { // ZALOZENIE: a-b musi byc istniejaca krawedzia
    node *a = &_node[_a], *b = &_node[_b];
    _change_root(a); _access(b); _splay(b);
    _set_child(b, NULL, 0); a->par = NULL;
}

void modify(int _a, int _b, modify_t v) { // ZALOZENIE: find_root(a) == find_root(b)
    node *a = &_node[_a], *b = &_node[_b];
    _change_root(a); _access(b); _splay(b);
    b->buf = op_buf(b->buf, v);
}

node_t query(int _a, int _b) { // ZALOZENIE: find_root(a) == find_root(b)
    node *a = &_node[_a], *b = &_node[_b];
    _change_root(a); _access(b); _splay(b);
    return b->res;
}

int find_root(int _x) {
    node *x = &_node[_x];
    _access(x); _splay(x);

    while(_left(x)) x = _left(x);
        _splay(x);
    return x-_node.data();
}

void _change_root(node *x) {
    _access(x); _splay(x); x->rev ^= 1;
}

void _access(node *x) {
    for(node *cur=NULL;x;x=x->par)
    {
        _splay(x);
        _set_child(x, cur, 1);
        cur = x;
    }
}

// SPLAY IMPLEMENTATION

bool _is_root(node *x) {
    return !x->par || (_right(x->par) != x && _left(x->par) != x);
}

void _push(node *x) {
    if(_left(x)) {
        _left(x)->rev ^= x->rev;
        _left(x)->buf = op_buf(_left(x)->buf, x->buf);
    }

    if(_right(x)) {
        _right(x)->rev ^= x->rev;
        _right(x)->buf = op_buf(_right(x)->buf, x->buf);
    }

    if(x->rev) {
        swap(_left(x), _right(x));
        x->rev = 0;
    }

    x->val = op_modify(x->val, x->buf);
    x->buf = MODIFY_NEUTRAL;
}

void _update(node *x) {
    x->res = x->val;
    if(_left(x))
        x->res = op_query(x->res, op_modify(_left(x)->res, _left(x)->buf));
    if(_right(x))
        x->res = op_query(x->res, op_modify(_right(x)->res, _right(x)->buf));
}

void _set_child(node *x, node *c, int t) {
    _push(x); x->child[t] = c;
    if(c) c->par = x;
        _update(x);
}

#define _is_left(x) (x == _left(x->par))

void _rotate(node *x) {
    node *p = x->par; x->par = p->par;
    if(!_is_root(p)) _set_child(p->par, x, !_is_left(p));
    int f = (x == _left(p));
    _set_child(p, x->child[f], !f);
    _set_child(x, p, f);
}

void _splay(node *x) {
    static vector<node*> r; node *p;
    for(p=x;!_is_root(p);p=p->par) r.PB(p);
    for(r.PB(p);!r.empty();r.pop_back()) _push(r.back());
    for(;!_is_root(x);_rotate(x))
    if(!_is_root(x->par) && _is_left(x) == _is_left(x->par))
        _rotate(x->par);
}
};

//#define dprintf(...) fprintf(stderr,__VA_ARGS__)
#define dprintf(...)

const int infty = 1e9+1;

struct edge_type
{
    int a, b, w;
};

bool operator<(edge_type e, edge_type f)
{
    return e.w < f.w;
}


vector< vector<PII> > stree;
int M;

void tree_init(int m)
{
    stree.clear();
    M = 1;
    while(M<m)
        M *= 2;
    stree.resize(2*M);
    for(int i=0; i<2*M; i++)
        stree[i].push_back(PII(infty,0));
}

void setval(int k, int v, int s)
{
    stree[M+k].push_back(PII(s,v));
    int x = (M+k)/2;
    while(x>0)
    {
        int w = stree[2*x].back().second+stree[2*x+1].back().second;
        if (stree[x].back().first==s)
            stree[x].pop_back();
        stree[x].push_back(PII(s,w));
        x = x/2;
    }
}

int sum(int s, int q)
{
    dprintf("Version %d, at most %d.\n",s,q);
    q += M;
    int res = 0;
    while(q>1)
    {
        dprintf("Node %d\n",q);
        if (q%2==1)
        {
            q--;
            dprintf("Taking node %d.\n",q);
            res += (upper_bound(stree[q].begin(),stree[q].end(),PII(s,-infty),greater<PII>())-1)->second;
        }
        q /= 2;
    }
    return res;
}

const int maxn = 1000;
const int maxm = 100000;
const int maxw = 1000*1000;
const int maxq = 1000*1000;

int main()
{
    oi::Scanner in(stdin);
    int TT = in.readInt(1, 1e9);
    in.readEoln();
    while(TT--)
    {
        int n = in.readInt(1,maxn);
        in.readSpace();
        int m = in.readInt(1,maxm);
        in.readEoln();
        vector<edge_type> edge(m);
        for(int i=0; i<m; i++)
        {
            edge[i].a = in.readInt(1,n);
            in.readSpace();
            edge[i].b = in.readInt(1,n);
            in.readSpace();
            if (edge[i].a==edge[i].b)
                in.error("Petla w grafie!\n");
            edge[i].w = in.readInt(1,maxw);
            in.readEoln();
        }
        sort(edge.begin(),edge.end());
        link_cut_tree L;
        L.init(n+m);
        for(int i=0; i<m; i++)
            L.modify(n+i,n+i,PII(i,edge[i].w));
        tree_init(m);
        for(int i=m-1; i>=0; i--)
        {
            dprintf("%d: Edge %d - %d (%d).\n",i,edge[i].a,edge[i].b,edge[i].w);
            int a = edge[i].a;
            int b = edge[i].b;
            if (L.find_root(a)==L.find_root(b))
            {
                int j = L.query(a,b).first;
                dprintf("Displacing %d (%d - %d).\n",j,edge[j].a,edge[j].b);
                setval(j,0,i);
                L.cut(edge[j].a,n+j);
                L.cut(edge[j].b,n+j);
            }
            L.link(a,n+i);
            L.link(b,n+i);
            setval(i,edge[i].w,i);
        }
        int ans = 0;
        int q = in.readInt(1,maxq);
        in.readEoln();
        for(int j=0; j<q; j++)
        {
            edge_type e;
            int x = in.readInt(1+ans,maxw+ans);
            in.readSpace();
            int y = in.readInt(1+ans,maxw+ans);
            in.readEoln();
            if (x>y)
                in.error("Dolne ograniczenie zapytania>gorne!\n");
            e.w = x - ans;
            int p = lower_bound(edge.begin(),edge.end(),e)-edge.begin();
            e.w = y - ans;
            int q = upper_bound(edge.begin(),edge.end(),e)-edge.begin();
            dprintf("Query %d: edges %d - %d.\n",j,p,q);
            ans = sum(p,q);
//            printf("%d\n",ans);
        }
    }
    in.readEof();
    printf("OK.\n");
}

